@@ -17,9 +17,12 @@ import numpy as np
 import torch
 from torch import nn
 import torch.utils.data
-from sklearn.neighbors import NearestNeighbors
-from scipy.sparse import csr_matrix, lil_matrix
+from sklearn.neighbors import NearestNeighbors, KNeighborsRegressor
+from scipy.sparse import csr_matrix, lil_matrix, coo_matrix
 from xclib.evaluation.xc_metrics import precision, ndcg
+from sklearn.preprocessing import normalize
+import os
+from .utils import data_iter
 
 
 # set random seeds
@@ -34,8 +37,8 @@ def set_seed(seed=0):
 
 
 class SparseKNeighborsRegressor:
-    def __init__(self, n_neighbors=5, weights='distance', metric='cosine'):
-        self.neighbors_model = NearestNeighbors(n_neighbors=n_neighbors, metric=metric, n_jobs=-1)
+    def __init__(self, n_neighbors=5, weights='distance', metric='cosine', n_jobs=-1):
+        self.neighbors_model = NearestNeighbors(n_neighbors=n_neighbors, metric=metric, n_jobs=n_jobs)
         self.weights = weights
 
     def fit(self, x_train, y_train):
@@ -47,8 +50,7 @@ class SparseKNeighborsRegressor:
         weights = self._get_weights(neigh_dist, self.weights)
         y_pred = lil_matrix((x_test.shape[0], self.y_train.shape[1]))
         denom = np.sum(weights, axis=1)
-        from tqdm import tqdm
-        for j in tqdm(range(self.y_train.shape[1])):
+        for j in range(self.y_train.shape[1]):
             num = np.sum(self.y_train[neigh_ind, j].toarray().reshape(weights.shape) * weights, axis=1)
             y_pred[:, j] = lil_matrix((num / denom).reshape(-1, 1))
         y_pred = csr_matrix(y_pred)
@@ -124,6 +126,12 @@ def get_data_loader(feature_matrix, class_matrix=None, batch_size=None, shuffle=
     return data_loader
 
 
+def to_sparse_tensor(matrix):
+    matrix = coo_matrix(matrix)
+    return torch.sparse.FloatTensor(torch.LongTensor(np.vstack((matrix.row, matrix.col))),
+                                    torch.FloatTensor(matrix.data), matrix.shape)
+
+
 def _single_precision(pred, true, k=5):
     index = pred.argsort()[::-1][:k]
     score = 0
